@@ -16,7 +16,7 @@
 #'   	If provided, plot(s) will replace the paragraph that contains the bookmark.\cr
 #'   	If not provided, plot(s) will be added at the end of the document.
 #' 
-#' @param parStyle paragraph formatting properties of the paragraph that contains plot(s). An object of class \code{\link{parProperties}}
+#' @param par.properties paragraph formatting properties of the paragraph that contains plot(s). An object of class \code{\link{parProperties}}
 #' @param pointsize the default pointsize of plotted text in pixels, default to getOption("ReporteRs-fontsize").
 #' @param fontname the default font family to use, default to getOption("ReporteRs-default-font").
 #' @param editable logical value - if TRUE vector graphics elements (points, texts, etc.) are editable.
@@ -24,38 +24,17 @@
 #' @return an object of class \code{"docx"}.
 #' @examples
 #' #START_TAG_TEST
-#' require( ggplot2 )
-#' 
-#' # Create a new document 
-#' doc = docx( title = "title" )
-#' 
-#' doc = addTitle( doc, "Plot 1", level = 1 )
-#' # Add a base plot - set vector.graphic to FALSE if Word version 
-#' # used to read the file is <= 2007
-#' doc = addPlot( doc, fun = plot
-#' 		, x = rnorm( 100 )
-#' 		, y = rnorm (100 )
-#' 		, main = "base plot main title"
-#' 		, vector.graphic = TRUE
-#' 		, width = 5, height = 7
-#' 		, parStyle = parProperties(text.align = "left")
-#' 	)
-#' 
-#' doc = addTitle( doc, "Plot 2", level = 1 )
-#' myplot = qplot(Sepal.Length, Petal.Length, data = iris, color = Species
-#' 	, size = Petal.Width, alpha = I(0.7))
-#' doc = addPlot( doc = doc
-#' 		, fun = print
-#' 		, x = myplot #this argument MUST be named, print is expecting argument 'x'
-#' 	)
-#' 
-#' # Write the object in file "addPlot_example.docx"
-#' writeDoc( doc, "addPlot_example.docx" )
-#' #STOP_TAG_TEST
+#' doc.filename = "addPlot_example.docx"
+#' @example examples/docx.R
+#' @example examples/addTitle1Level1.R
+#' @example examples/addBasePlot_vg.R
+#' @example examples/addTitle2Level1.R
+#' @example examples/addggplot.R
+#' @example examples/writeDoc_file.R
+#' @example examples/STOP_TAG_TEST.R
 #' @seealso \code{\link{docx}}, \code{\link{addPlot}}
 #' @method addPlot docx
 #' @S3method addPlot docx
-
 addPlot.docx = function(doc, fun
 		, pointsize = getOption("ReporteRs-fontsize")
 		, vector.graphic = F
@@ -63,7 +42,7 @@ addPlot.docx = function(doc, fun
 		, fontname = getOption("ReporteRs-default-font")
 		, editable = TRUE
 		, bookmark 
-		, parStyle = parProperties(text.align = "center", padding = 5 )
+		, par.properties = parProperties(text.align = "center", padding = 5 )
 		, ... ) {
 
 	plotargs = list(...)
@@ -88,24 +67,24 @@ addPlot.docx = function(doc, fun
 		# Send the graph to java that will 'encode64ize' and place it in a docx4J object
 		if( missing( bookmark ) )
 			.jcall( doc$obj, "V", "addImage", .jarray( plotfiles ), .jarray(dims)
-					, parStyle$text.align
-					, parStyle$padding.bottom
-					, parStyle$padding.top
-					, parStyle$padding.left
-					, parStyle$padding.right
+					, par.properties$text.align
+					, par.properties$padding.bottom
+					, par.properties$padding.top
+					, par.properties$padding.left
+					, par.properties$padding.right
 			)
 		else .jcall( doc$obj, "V", "insertImage", bookmark, .jarray( plotfiles ), .jarray(dims)
-					, parStyle$text.align
-					, parStyle$padding.bottom
-					, parStyle$padding.top
-					, parStyle$padding.left
-					, parStyle$padding.right
+					, par.properties$text.align
+					, par.properties$padding.bottom
+					, par.properties$padding.top
+					, par.properties$padding.left
+					, par.properties$padding.right
 			)
 	} else {
 		# one important and painful point is that shape ids must be unique 
 		# in the whole document
 		last_docx_elt_index = .jcall( doc$obj, "I", "getElementIndex") + 1L
-		# OK, maybe start_id should be named last_id... 
+		# start_id should be named last_id... 
 		doc_elt_index = last_docx_elt_index;
 		filename = file.path( dirname, "dml", fsep = "/"  )
 		filename = normalizePath( filename, winslash = "/", mustWork  = FALSE)
@@ -117,7 +96,6 @@ addPlot.docx = function(doc, fun
 		fun_res = try( fun(...), silent = T )
 		last_id = .C("get_current_element_id", (dev.cur()-1L), 0L)[[2]]
 		
-#		browser()
 		dev.off()
 		
 
@@ -129,19 +107,19 @@ addPlot.docx = function(doc, fun
 		if( missing( bookmark ) ){
 			
 			.jcall( doc$obj, "V", "addDML", .jarray( plotfiles ), .jarray(dims)
-					, parStyle$text.align
-					, parStyle$padding.bottom
-					, parStyle$padding.top
-					, parStyle$padding.left
-					, parStyle$padding.right
+					, par.properties$text.align
+					, par.properties$padding.bottom
+					, par.properties$padding.top
+					, par.properties$padding.left
+					, par.properties$padding.right
 					)
 		} else {
 			.jcall( doc$obj, "V", "insertDML", bookmark, .jarray( plotfiles ), .jarray(dims) 
-					, parStyle$text.align
-					, parStyle$padding.bottom
-					, parStyle$padding.top
-					, parStyle$padding.left
-					, parStyle$padding.right
+					, par.properties$text.align
+					, par.properties$padding.bottom
+					, par.properties$padding.top
+					, par.properties$padding.left
+					, par.properties$padding.right
 					)
 		}
 	}
