@@ -1,17 +1,17 @@
 class.docx4r.DataTable = "org/lysis/reporters/docx4r/elements/DataTable"
 class.docx4r.POT = "org/lysis/reporters/docx4r/elements/POT"
 class.fontMetric = "org/lysis/reporters/graphicaldevices/fonts/FontMetric"
+class.fontInfo = "org/lysis/reporters/graphicaldevices/fonts/FontInfo"
 class.html4r.DataTable = "org/lysis/reporters/html4r/elements/DataTable"
 class.html4r.POT = "org/lysis/reporters/html4r/elements/POT"
-class.html4r.RScript = "org/lysis/reporters/html4r/elements/RScript"
 class.html4r.ImagesList = "org/lysis/reporters/html4r/elements/ImagesList"
 class.html4r.POTsList = "org/lysis/reporters/html4r/elements/SetOfPot"
-class.html4r.RaphaelList = "org/lysis/reporters/html4r/elements/SetOfRaphaelPlots"
+class.html4r.RAPHAELGraphics = "org/lysis/reporters/html4r/elements/RAPHAELGraphics"
 class.html4r.Title = "org/lysis/reporters/html4r/elements/Title"
 class.pptx4r.DataTable = "org/lysis/reporters/pptx4r/elements/DataTable"
-class.pptx4r.DrawingMLList = "org/lysis/reporters/pptx4r/elements/DrawingMLPlot"
+class.pptx4r.DMLGraphics = "org/lysis/reporters/pptx4r/elements/DMLGraphics"
 class.pptx4r.SlideLayout = "org/lysis/reporters/pptx4r/elements/layouts/SlideLayout"
-class.pptx4r.POT = "org/lysis/reporters/pptx4r/elements/POT"
+class.pptx4r.Paragraphs = "org/lysis/reporters/pptx4r/elements/Paragraphs"
 class.docx4r.TableLayoutDOCX = "org/lysis/reporters/tables/TableLayoutDOCX"
 class.html4r.TableLayoutHTML = "org/lysis/reporters/tables/TableLayoutHTML"
 class.pptx4r.TableLayoutPPTX = "org/lysis/reporters/tables/TableLayoutPPTX"
