@@ -5,6 +5,7 @@
 #' @param doc Object of class \code{docx} to extract style names from.
 #' @param ... further arguments, not used. 
 #' @details Available styles will be paragraph styles of the base document (e.g. Normal, Title1, etc.).
+#' Names of the returned character vector are labels associated with styles names.
 #' @examples
 #' #START_TAG_TEST
 #' # Create a new document 
@@ -16,7 +17,14 @@
 #' @S3method styles docx
 
 styles.docx = function( doc, ... ) {
-	.jcall( doc$obj, "[S", "getStyleNames" )
-	}
+  .names = .jcall( doc$obj, "[S", "getStyleNames" )
+  .l = length(.names) / 2
+  
+  if( .l < 1 ) return(character(0))
+  
+  out = .names[1:.l]
+  names( out ) = .names[(.l+1):length(.names)]
+  out
+  }
 
 
